### Notas de las versiones:

- 1.3:
  -- strings: cifrar, descifrar
- 1.2:
  -- Módulo QueryBuilder.
- 1.1.1:
  -- objetos -> dicts: Optimizaciones.
- 1.1:
  -- strings: remover_acentos, limpiar_string
- 0.1: Subida inicial.
  -- objetos: Obj
